@@ -179,9 +179,11 @@ class Automation:
             return False
 
         base_class = ''
-        if issubclass(type(task), (IntegrationTask, LogicModuleTask, AnalyticsTask, EventWorkOrderTask,
-                                   DiscoverableIntegrationTask)):
-            base_class = task.__class__.__qualname__
+        allowed_base_classes = tuple([Task] + Task.__subclasses__())
+        # allowed_base_classes = tuple(
+        #     ['Task'] + [allowed_base_classes[i].__qualname__ for i in range(len(allowed_base_classes))])
+        if issubclass(type(task), allowed_base_classes):
+            base_class = task.__class__.__base__.__qualname__
         # elif issubclass(type(task), LogicModuleTask):
         #     base_class = 'LogicModuleTask'
         # elif issubclass(type(task), AnalyticsTask):
@@ -194,6 +196,9 @@ class Automation:
                 'Task must be an implementation of one of the Task sub-classes: IntegrationTask, LogicModuleTask, '
                 'AnalyticsTask, EventWorkOrderTask, DiscoverableIntegrationTask.')
             return pandas.DataFrame()
+        elif not set([base_class]).issubset({allowed_base_classes[i].__qualname__ for i in range(len(allowed_base_classes))}):
+            logger.error(f"Task must be an implementation of one of the Task sub-classes: IntegrationTask, "
+                         f"LogicModuleTask, AnalyticsTask, EventWorkOrderTask, DiscoverableIntegrationTask.)")
 
         if type(task.mapping_entities) != list:
             logger.error('The mapping_entities parameter must have type = list. ')
@@ -754,7 +759,6 @@ class Automation:
 
 
 
-        # # TODO - discuss whether this is required since we added the Literal EXPECTED_DELIVERY
         # expected_deliveries = re.findall(r'[A-Za-z]+|\d+', expected_delivery)
         # if len(expected_deliveries) != 2 or expected_deliveries[0].isnumeric() is not True:
         #     logger.error("Run At parameter must take the form of a number followed by a time type. ")
@@ -807,7 +811,7 @@ class Automation:
 
     @staticmethod
     def cancel_deployed_timer(api_inputs: ApiInputs, data_feed_id: uuid.UUID):
-        """Deploy driver to run on timer.
+        """Cancel deployed timer for a given `data_feed_id`.
 
         Parameters
         ----------
@@ -830,7 +834,6 @@ class Automation:
 
         headers = api_inputs.api_headers.default
 
-        # TODO: Please review Kate. Removed checking of Deployment Type of Timer and added required parameter of Data Feed Id
         if (data_feed_id == None):
             logger.error('Data feed Id cannot be None')
             return
@@ -840,7 +843,6 @@ class Automation:
         logger.info("Cancel deploy with DataFeedID: %s for ApiProjectID: %s", data_feed_id, api_inputs.api_project_id)
         logger.info("Sending request: POST %s", url)
 
-        # TODO: Please review Kate. Changed method to POST instead of GET, to align with API
         response = requests.post(url, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
         if response.status_code != 200:
